{% load i18n %} {% load templates %}
{% trans 'Utilisateur' %}
{% trans 'Objet' %}
{% for hist in object_list %}
{{ hist.user }}
{{ hist.date |date:'d/m/Y'}}
{{ hist.date |date:'H:i:s'}}
{% if hist.changeReason %}
{{ hist.changeReason }}
{% endif %}
{{ hist.history_object.instance.history.most_recent }} ({{ hist.history_object.instance | to_class_name }})
{% for change in hist.get_changes %}
{{ change.field }} :
{{ change.old }}
{{ change.new }}
{% endfor %}
{% endfor %}